@@ -39,7 +39,7 @@
 
 extern "C"
 {
-    KPanelApplet* init(QWidget *parent, const QString& configFile)
+    KDE_EXPORT KPanelApplet* init(QWidget *parent, const QString& configFile)
     {
         KGlobal::locale()->insertCatalogue("kweather");
         kweather *theApplet = new kweather(configFile, KPanelApplet::Normal,
@@ -283,7 +283,8 @@ void kweather::timeout(){
 
 int kweather::widthForHeight(int h) const
 {
-	kdDebug(12004) << "widthForHeight " << h << endl;
+	//kdDebug(12004) << "widthForHeight " << h << endl;
+	dockWidget->setOrientation(Horizontal);
 	int w = dockWidget->widthForHeight(h);
 	return w;
 }
@@ -291,6 +292,7 @@ int kweather::widthForHeight(int h) const
 int kweather::heightForWidth(int w) const
 {
 	kdDebug(12004) << "heightForWidth " << w<< endl;
+	dockWidget->setOrientation(Vertical);
 	int h = dockWidget->heightForWidth( w );
 	return h;
 }
@@ -356,6 +358,9 @@ void kweather::mousePressEvent(QMouseEvent *e)
 
 void kweather::slotUpdateNow()
 {
+    if ( !mWeatherService )
+         initDCOP();
+
     mWeatherService->forceUpdate(reportLocation );
 }
 
